/**
 * Gulp tasks for wrapping Browserify modules.
 */
const display = require("./util/display");
const gulp = require("gulp");
const browserify = require("browserify");
const source = require("vinyl-source-stream");
const buffer = require("vinyl-buffer");
const uc = require("./util/unite-config");
const clientPackages = require("./util/client-packages");
const gutil = require("gulp-util");
const uglify = require("gulp-uglify");

gulp.task("build-bundle-vendor", () => {
    const uniteConfig = uc.getUniteConfig();
    const buildConfiguration = uc.getBuildConfiguration();

    if (buildConfiguration.bundle) {
        display.info("Running", "Browserify for Vendor");

        const bVendor = browserify({"debug": buildConfiguration.sourcemaps});

        const keys = clientPackages.getKeys(uniteConfig);

        const idx = keys.indexOf("systemjs");
        if (idx >= 0) {
            keys.splice(idx, 1);
        }

        keys.forEach((key) => {
            bVendor.require(key);
        });

        if (buildConfiguration.minify) {
            process.env.NODE_ENV = "production";
        }

        return bVendor.bundle()
            .pipe(source("vendor-bundle.js"))
            .pipe(buffer())
            .pipe(buildConfiguration.minify ? uglify()
                .on("error", (err) => {
                    display.error(err.toString());
                }) : gutil.noop())
            .pipe(gulp.dest(uniteConfig.directories.dist));
    }
});

/* Generated by UniteJS */
