/**
 * Gulp tasks for webdriverio e2e testing.
 */
const display = require("./util/display");
const gulp = require("gulp");
const uc = require("./util/unite-config");
const path = require("path");
const webdriver = require("gulp-webdriver");
const selenium = require("selenium-standalone");
const browserSync = require("browser-sync");
const allure = require("allure-commandline");

let seleniumInstance = null;
let browserSyncInstance = null;

gulp.task("e2e-run-test", (done) => {
    display.info("Running", "WebdriverIO");

    const uniteConfig = uc.getUniteConfig();

    gulp.src("wdio.conf.js")
        .pipe(webdriver())
        .on("error", () => {
            seleniumInstance.kill();
            browserSyncInstance.exit();
            process.exit(1);
        })
        .on("end", () => {
            seleniumInstance.kill();
            browserSyncInstance.exit();

            display.info("Running", "Allure Report Generation");
            const generation = allure([
                "generate",
                path.join(uniteConfig.directories.reports, "/e2etemp/"),
                "-o",
                path.join(uniteConfig.directories.reports, "/e2e/")
            ]);

            generation.on("exit", () => {
                done();
            });
        });
});

gulp.task("e2e-serve", (done) => {
    display.info("Running", "BrowserSync");

    browserSyncInstance = browserSync.create();
    browserSyncInstance.init({
        "https": false,
        "notify": false,
        "online": true,
        "open": false,
        "port": 9000,
        "server": {"baseDir": ["."]}
    });

    display.info("Running", "Selenium");
    selenium.start((err, child) => {
        if (err) {
            display.error(err);
            process.exit(1);
        } else {
            seleniumInstance = child;
            done();
        }
    });
});

/* Generated by UniteJS */
